{% extends 'projects/project_base.html' %}

{% block title %} Feature matrix list {% endblock %}

{% block nav2 %}
{% endblock %}

{% block content2 %}
<h2> Refer evaluation of feature matrix </h2>
<table id="feature_matrices" class="stripe hover row-border order-column cell-border">
  <thead>
    <tr>
      <th>ID</th>
      <th>Name</th>
      <th>Created</th>
      <th>Note</th>
    </tr>
  </thead>
  <tbody>
    {% for fm, url in contexts %}
      <tr>
          <td><a href="{{ url }}"> {{ fm.fm_id }} </a></td>
        <td>{{ fm.name }}</td>
        <td>{{ fm.created }}</td>
        <td>{{ fm.note }}</td>
      </tr>
    {% endfor %}
  </tbody>
</table>
{% endblock %}

{% block scripts2 %}
  <script>
    $(document).ready(function () {
      $('#feature_matrices').DataTable({
        columns: [
            {className: 'dt-right'},
            {className: 'dt-right'},
            {searchable: false, className: 'dt-right'},
            {orderable: false, className: 'dt-left'}
        ],
      });
    });
  </script>
{% endblock %}
