{% extends 'base.html' %}

{% block title %} Project creation {% endblock %}

{% block nav %}
{% endblock %}

{% block header %}
    <h2>Create a New Project</h2>
{% endblock %}

{% block content %}
<form method="post">
    <label for="name">Name</label>
    <input name="name" id="name" required>
    <label for="note">(Optional) Note</label>
    <input name="note" id="note">
    <input type="submit" value="Create">
</form>
{% endblock %}
